<?php

namespace Litecms\Property\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Property\Models\PropertyType;

class PropertyTypePolicy
{

    /**
     * Determine if the given user can view the property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function view(UserPolicy $user, PropertyType $property_type)
    {
        if ($user->canDo('property.property_type.view') && $user->isAdmin()) {
            return true;
        }

        return $property_type->user_id == user_id() && $property_type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('property.property_type.create');
    }

    /**
     * Determine if the given user can update the given property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function update(UserPolicy $user, PropertyType $property_type)
    {
        if ($user->canDo('property.property_type.edit') && $user->isAdmin()) {
            return true;
        }

        return $property_type->user_id == user_id() && $property_type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PropertyType $property_type)
    {
        return $property_type->user_id == user_id() && $property_type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PropertyType $property_type)
    {
        if ($user->canDo('property.property_type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property_type.
     *
     * @param UserPolicy $user
     * @param PropertyType $property_type
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PropertyType $property_type)
    {
        if ($user->canDo('property.property_type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
